'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const SquashedPod = require('./../SquashedPod');

const expect = chai.expect;
chai.use(sinonChai);

function getFakePod(){
    return {
        getOwnerReferences(){
            return []
        },
        getImages(){
            return [
                {
                    name: 'image',
                    imageID: 'id1',
                },
            ];
        },
        getLabels(){
            return [
                'a=b',
                'c=d'
            ]
        },
        getName: () => 'fake-pod-name',
        getStartTime: () => new Date(1970).toDateString(),
        getEntityStatus:() => {}
    }
}

describe('Squashed pod', () => {
    it('Should create squashed pod from pod', () => {
        expect((new SquashedPod(getFakePod())).toJson()).to.be.deep.equal(
            {
                'images': [
                    {
                        "imageID": 'id1',
                        "name": "image"
                    }
                ],
                "labels": [
                    "a=b",
                    "c=d"
                ],
                "relatedPods": [
                    {
                        "name": "fake-pod-name",
                        "status": undefined
                    }
                ],
                "startTime": "Thu Jan 01 1970"
            }
        );
    });

    it('Should add id to image', () => {
        const pod = getFakePod();
        const sp = new SquashedPod(pod);
        sp.setImageMetaData('image', 'internalId', 'id');
        expect(sp.getImages()[0].internalId).to.be.deep.equal('id');
    });
});
