'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const SPP = require('./../SquashedPodPool');
const SquashedPol = require('./../SquashedPod');

const expect = chai.expect;
chai.use(sinonChai);

function getFakePod(data){
    return {
        getOwnerReferences(){
            return data || [];
        },
        getImages:() => [],
        getLabels:() => [],
        getName: () => 'fake-pod-name',
        getStartTime: () => new Date(1970).toDateString(),
        getEntityStatus:() => {}
    }
}

function getFakeSquashedPod(data){
    return new SquashedPol(getFakePod(data));
}

describe('Squashed pod pool', () => {
    it('Should init new empty pool', () => {
        expect(new SPP().pool).to.be.deep.equal([]);
    });

    it('Should add squashed pod to the pool', () => {
        const pool = new SPP();
        pool.add(getFakeSquashedPod());
        expect(pool.pool.length).to.be.equal(1);
    });

    it('isExist should return true when trying to add same SquashedPod', () => {
        const pool = new SPP();
        const sqp = getFakeSquashedPod();
        pool.add(sqp);
        expect(pool.isExist(sqp)).to.be.equal(true)
    });

    it('Should return false when trying to add different SquashedPods to the pool', () => {
        const pool = new SPP();
        const sqp1 = getFakeSquashedPod();
        const sqp2 = getFakeSquashedPod([{}]);
        pool.add(sqp1);
        expect(pool.isExist(sqp2)).to.be.equal(false)
    });
});

