'use strict';

const Promise = require('bluebird');
const _       = require('lodash');
const Base    = require('./../resource.base.controller');

class DeployController extends Base {

    delete(name) {
        const kubeManager          = this._kubeManager;
        const ns                   = this._ns;
        const replicasetController = kubeManager.getReplicasetController.bind(kubeManager);
        const podController        = kubeManager.getPodController.bind(kubeManager);

        return this.describe(name)
            .then((deploy) => {
                let deploySelectors = deploy.getMatchLabelSelector();
                const selectors = [];
                _.keys(deploySelectors).forEach((key) => {
                    selectors.push(`${key}=${deploySelectors[key]}`);
                });
                deploySelectors = selectors.join(',');
                const promises = [];
                if (deploy) {
                    const deployDeletePromise = super.delete(deploy.getName());
                    const rsPromises          = replicasetController(ns)
                        .get({ labelSelector: deploySelectors })
                        .then((data) => {
                            return data;
                        })
                        .map(rs => replicasetController(ns).delete(rs.getName()));
                    const podPromises         = podController(ns)
                        .get({ labelSelector: deploySelectors })
                        .then((data) => {
                            return data;
                        })
                        .map(pod => podController(ns).delete(pod.getName()));
                    promises.push([deployDeletePromise, rsPromises, podPromises]);
                }
                return Promise.all(_.flattenDeep(promises));
            });

    }

}

module.exports = DeployController;