'use strict';

const _          = require('lodash');
const BaseEntity = require('./../../kube-native/entity.base');

class Deployment extends BaseEntity {

    addSpecTemplateMetadataAnnotations(data){
        _.set(this._getData(), 'spec.template.metadata.annotations', Object.assign(this.getSpecTemplateMetadataAnnotations(), data));
    }

    getSpecTemplateMetadataAnnotations(){
        return _.get(this._getData(), 'spec.template.metadata.annotations', {});
    }

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getNamespace() {
        return _.get(this._getData(), 'metadata.namespace');
    }

    getMatchLabelSelector(){
        return _.get(this._getData(), 'spec.selector.matchLabels');
    }

    replaceImageInContainerByContainerName(containerName, newImage){
        _.set(this.getContainerByName(containerName), 'image', newImage);
    }

    addImagePullSecret(name){
        const pullSecrets = this.getImagePullSecrets();
        if(!pullSecrets.includes(name)) {
            _.set(this._getData(), 'spec.template.spec.imagePullSecret', [{ name }]);
        }
    }

    getImagePullSecrets(){
        return _.get(this._getData(), 'spec.template.spec.imagePullSecrets', []);
    }

    getTemplateSpec(){
        return _.get(this._getData(), 'spec.template.spec', {});
    }

    /**
     * Return first container with given name
     * @param name
     */
    getContainerByName(name){
        return _.chain(this._getData())
            .get('spec.template.spec.containers', [])
            .find(container => container.name === name)
            .value();
    }

    getBasicData() {
        return {
            name: this.getName(),
            status: this.getStatus(),
            namespace: this.getNamespace(),
            selector: this.getSelector(),
            entityStatus: this.getEntityStatus()
        }
    }
}

module.exports = Deployment;
