'use strict';

const chai          = require('chai');
const sinonChai     = require('sinon-chai');
const _             = require('lodash');
const Deploy        = require('./../deploy');

const expect = chai.expect;
chai.use(sinonChai);


function getFakeDeployment(){
    return new Deploy({
        spec: {
            template: {
                spec: {
                    containers: [
                        {
                            name: 'fake-container-1',
                            image: 'fake-image-1:fake-tag'
                        },
                        {
                            name: 'fake-container-2',
                            image: 'fake-registry/fake-image:latest'
                        }
                    ]
                }
            }
        }
    });
}

describe('Deploy unit test', () => {

    it('Should get the container by given name', () => {
        const deployment = getFakeDeployment();
        expect(deployment.getContainerByName('fake-container-1').name).to.be.deep.equal('fake-container-1');
        expect(deployment.getContainerByName('fake-container-2').name).to.be.deep.equal('fake-container-2');
    });

    it('Should replace image for container', () => {
        const deployment = getFakeDeployment();
        deployment.replaceImageInContainerByContainerName('fake-container-1', 'other-image');
        expect(deployment.getContainerByName('fake-container-1').image).to.be.deep.equal('other-image');
    });

    it('Should add image pull secret', () => {
        const deployment = getFakeDeployment();
        deployment.addImagePullSecret('fake-secret');
         expect(deployment.getTemplateSpec().imagePullSecret)
            .to
            .be
            .deep
            .equal([{ name: 'fake-secret' }]);
    });

    it('Should set metadata annotations', () => {
        const deployment = getFakeDeployment();
        deployment.addSpecTemplateMetadataAnnotations({ forceRedeployUniqueId: "123"});
        expect(deployment.getSpecTemplateMetadataAnnotations()).to.be.deep.equal({ forceRedeployUniqueId: "123"});
    });

});