'use strict';

const BaseEntity = require('./../entity.base');
const _          = require('lodash');

class Node extends BaseEntity {

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getStatus() {
        let conditions = _.get(this._getData(), 'status.conditions') || [];
        return conditions.filter((condition) => condition.type === 'Ready').pop();
    }

    getInternalIP() {
        let addresses = _.get(this._getData(), 'status.addresses') || [];
        let address = addresses.filter((address) => address.type === 'InternalIP').pop();
        return _.get(address, 'address') || 'N/A';
    }

    getExternalIP() {
        let addresses = _.get(this._getData(), 'status.addresses') || [];
        let address = addresses.filter((address) => address.type === 'ExternalIP').pop();
        return _.get(address, 'address') || 'N/A';
    }

    getCreatedAt() {
        return _.get(this._getData(), 'metadata.creationTimestamp');
    }

    getLabels() {
        return _.get(this._getData(), 'metadata.labels');
    }

    getBasicData() {
        const status = this.getStatus();

        return {
            name: this.getName(),
            createdAt: this.getCreatedAt(),
            labels: this.getLabels(),
            address: {
              internal: this.getInternalIP(),
              external: this.getExternalIP()
            },
            status: {
              message: status.message,
              status: status.status === 'True'
            }
        }
    }

}

module.exports = Node;
