'use strict';

const _ = require('lodash');

const Base = require('./../../status.analyzer.base');

class ReplicaSetStatusAnalyzer extends Base {

    /**
     * Replicaset doesn't have clear status but only indicators about replicas, available, ready
     * RS will be marked as SUCCESS when the readyReplicas == availableReplicas == replicas
     * Otherwise it will have a IN_PROGRESS status without any message atm
     */
    analyze() {
        this._finalStauts = Base.types.unknown;

        const readyReplicas        = _.get(this, '_status.readyReplicas');
        const fullyLabeledReplicas = _.get(this, '_status.fullyLabeledReplicas');
        const observedGeneration   = _.get(this, '_status.observedGeneration');
        const replicas             = _.get(this, '_status.replicas');
        const availableReplicas    = _.get(this, '_status.availableReplicas');


        if (!_.isNumber(replicas)) {
            this._finalStauts = Base.types.unknown;
        }

        if(availableReplicas == readyReplicas && readyReplicas == replicas){
            this._finalStauts = Base.types.suceess;
        } else {
            this._finalStauts = Base.types.inProgress;
        }

        return _.merge({}, this._finalStauts, {
            givenStatus: this._status,
            resouceType: this._resource
        });
    }


}


module.exports = ReplicaSetStatusAnalyzer;