'use strict';

const crypto      = require('crypto');
const _           = require('lodash');
const BaseBuilder = require('./../builder.base');

class ImagePullSecretBuilder extends BaseBuilder {

    constructor(descriptor, opt) {

        const template = {
            apiVersion: 'v1',
            kind: 'Secret',
            metadata: {
                name: descriptor.name
            },
            namespace: `default`,
            type: `kubernetes.io/dockercfg`

        };
        super(descriptor, template, opt);
    }

    _startBuild() {
        this._buildSecret();
    }


    _buildSecret() {
        const domain    = this._getRegistryDomain();
        const credentials = this._getCredentials();
        this.updateTemplate(`stringData`, {
            ".dockercfg": `{"${domain}": ${JSON.stringify({
                'auth': new Buffer(`${credentials.username}:${credentials.password}`).toString('base64')
            })}}`
        });
        this.updateTemplate('metadata.labels', this._getLabels());
        return this;
    }


    _getRegistryDomain() {
        return this.getDescriptor().domain;
    }

    _getCredentials() {
        return this.getDescriptor().credentials;
    }

    _getLabels(){
        return _.merge(this.getDescriptor().labels, {
            'io.codefresh.generated-at': Date.now().toString()
        });
    }
}

module.exports = ImagePullSecretBuilder;