'use strict';

const BaseBuilder = require('./../builder.base');

class SecretBuilder extends BaseBuilder {

    constructor(descriptor, opt) {

        const template = {
            apiVersion: 'v1',
            kind: 'Secret',
            metadata: {
                name: descriptor.name
            },
            namespace: `default`,
            type: `kubernetes.io/dockercfg`

        };
        super(descriptor, template, opt);
    }

    _startBuild() {
        this._buildSecret();
    }

    _buildSecret(){
        const registry = this._getRegistry();
        const credentials = this._getCredentials();
        this.updateTemplate(`stringData`, {
            ".dockercfg": `{"${registry}": ${JSON.stringify(credentials)}}`
        });
        return this;
    }

    _getRegistry(){
        return this.getDescriptor().registry;
    }

    _getCredentials(){
        return this.getDescriptor().credentials;
    }
}

module.exports = SecretBuilder;