'use strict';

const _           = require('lodash');
const BaseBuilder = require('./../../kube-native/builder.base');
const uuidv4      = require('uuid/v4');

class ServiceBuilder extends BaseBuilder {

    constructor(descriptor, opt) {
        const template = {
            apiVersion: 'v1',
            kind: 'Service',
            metadata: {
                name: descriptor.metadata.name
            },
            spec: {
                type: _.get(descriptor, 'spec.type', 'ClusterIP'),
                selector: {
                    app: descriptor.metadata.name
                }
            }
        };
        super(descriptor, template, opt);

    }

    _startBuild() {
        this._buildPorts()
            ._buildLabels();
    }

    _getPorts() {
        const svcDescriptor = this.getDescriptor();
        const ports         = _.get(svcDescriptor, 'spec.ports', [])
            .map((port) => {
                const portTemplate = {
                    name: port.name,
                    targetPort: port.targetPort,
                    protocol: port.protocol || 'TCP'
                };
                if (port.port) {
                    portTemplate.port = port.port;
                }
                return portTemplate;
        });
        return ports;
    }

    _shouldBuildPorts() {
        return !!_.get(this.getDescriptor(), 'spec.ports' ,false);
    }

    _buildPorts() {
        this._shouldBuildPorts() && this.updateTemplate('spec.ports', this._getPorts());
        return this;
    }

    _buildLabels(){
        this.shouldMarkWithLabels() && this.updateTemplate('metadata.labels', {
            ['io.codefresh.auto-generated']: uuidv4(),
            ['io.codefresh.generated-at']: Date.now().toString()
        });
        return this;
    }
}

module.exports = ServiceBuilder;