'use strict';

const chai = require('chai');
const sinonChai = require('sinon-chai');
const _ = require('lodash');
const ServiceCtrl = require('../svc.controller');
const StatusAnalyzer = require('../../../status.analyzer.base');

const expect = chai.expect;
chai.use(sinonChai);


function getFakeKubeManager(serviceSelector){
    return {
        getDeploymentController: () => ({
            get: async () => {
                return {};
            }
        }),
        getReplicasetController: () => ({
            get: async () => {
                return {};
            }
        }),
        getPodController: () => ({
            get: async () => {
                return {};
            }
        }),
        getServiceController: () => ({
            describe: async () => {
                return {
                    getServiceSelector: () => serviceSelector,
                    getBasicData: () => ({
                        data: 'basic data',
                    }),
                    getEntityStatus: () => ({
                        status: StatusAnalyzer.types.suceess.status,
                    }),
                };
            },
        }),
        getNamespaceController: () => ({
            get: async () => {
                return {};
            }
        }),
    }
}

describe('Service describeFull', () => {
    it('describeFull should return correct data', async () => {
        const kubeManager = getFakeKubeManager();
        const serviceCtrl = new ServiceCtrl({ kubeManager });
        const result = await serviceCtrl.describeFull('name', 'namespace');
        expect(result).to.be.deep.equal({
            data: 'basic data',
            globalStatus: {
                type: 'SUCCESS',
                resources: {
                    deployment: undefined,
                    pods: undefined,
                    replicaSets: undefined,
                    svc: {
                        status: 'SUCCESS'
                    }
                }
            }
        });
    });
});
