'use strict';

const chai          = require('chai');
const sinonChai     = require('sinon-chai');
const _             = require('lodash');
const Base        = require('./../entity.base');

const expect = chai.expect;
chai.use(sinonChai);


function getFakeBaseEntity(){
    return new Base({
        metadata: {
            labels: {}
        }
    });
}

describe('Base entity test', () => {
    it('Should add labels', () => {
        const en = getFakeBaseEntity();
        en.addLabels({
            a: 1,
            b: 2
        });
        expect(en.getLabels()).to.be.deep.equal({
            a: 1,
            b: 2
        });
    });

    it('Should overwrite existing labels with given', () => {
        const en = getFakeBaseEntity();
        en.addLabels({
            a: 1,
            b: 2
        });
        en.addLabels({
            a: 3,
            c: 4
        });
        expect(en.getLabels()).to.be.deep.equal({
            a: 3,
            b: 2,
            c: 4
        });
    });

    it('Should add to when no labels exist', () => {
        const en = new Base({});
        en.addLabels({
            a: 1
        });
        expect(en.getLabels()).to.be.deep.equal({a: 1});
    });
});